GooglePrivacyDlpV2Action

Struct GooglePrivacyDlpV2Action 

pub struct GooglePrivacyDlpV2Action {
    pub deidentify: Option<GooglePrivacyDlpV2Deidentify>,
    pub job_notification_emails: Option<GooglePrivacyDlpV2JobNotificationEmails>,
    pub pub_sub: Option<GooglePrivacyDlpV2PublishToPubSub>,
    pub publish_findings_to_cloud_data_catalog: Option<GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog>,
    pub publish_findings_to_dataplex_catalog: Option<GooglePrivacyDlpV2PublishFindingsToDataplexCatalog>,
    pub publish_summary_to_cscc: Option<GooglePrivacyDlpV2PublishSummaryToCscc>,
    pub publish_to_stackdriver: Option<GooglePrivacyDlpV2PublishToStackdriver>,
    pub save_findings: Option<GooglePrivacyDlpV2SaveFindings>,
}
A task to execute on the completion of a job. See https://cloud.google.com/sensitive-data-protection/docs/concepts-actions to learn more.

This type is not used in any activity, and only used as part of another schema.

Fields

deidentify: Option<GooglePrivacyDlpV2Deidentify>

Create a de-identified copy of the input data.

job_notification_emails: Option<GooglePrivacyDlpV2JobNotificationEmails>

Sends an email when the job completes. The email goes to IAM project owners and technical Essential Contacts.

pub_sub: Option<GooglePrivacyDlpV2PublishToPubSub>

Publish a notification to a Pub/Sub topic.

publish_findings_to_cloud_data_catalog: Option<GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog>

Deprecated because Data Catalog is being turned down. Use publish_findings_to_dataplex_catalog to publish findings to Dataplex Universal Catalog.

publish_findings_to_dataplex_catalog: Option<GooglePrivacyDlpV2PublishFindingsToDataplexCatalog>

Publish findings as an aspect to Dataplex Universal Catalog.

publish_summary_to_cscc: Option<GooglePrivacyDlpV2PublishSummaryToCscc>

Publish summary to Cloud Security Command Center (Alpha).

publish_to_stackdriver: Option<GooglePrivacyDlpV2PublishToStackdriver>

Enable Stackdriver metric dlp.googleapis.com/finding_count.

save_findings: Option<GooglePrivacyDlpV2SaveFindings>

Save resulting findings in a provided location.