GooglePrivacyDlpV2CloudStorageOptions

Struct GooglePrivacyDlpV2CloudStorageOptions 

pub struct GooglePrivacyDlpV2CloudStorageOptions {
    pub bytes_limit_per_file: Option<i64>,
    pub bytes_limit_per_file_percent: Option<i32>,
    pub file_set: Option<GooglePrivacyDlpV2FileSet>,
    pub file_types: Option<Vec<String>>,
    pub files_limit_percent: Option<i32>,
    pub sample_method: Option<String>,
}
Options defining a file or a set of files within a Cloud Storage bucket.

This type is not used in any activity, and only used as part of another schema.

Fields

bytes_limit_per_file: Option<i64>

Max number of bytes to scan from a file. If a scanned file’s size is bigger than this value then the rest of the bytes are omitted. Only one of bytes_limit_per_file and bytes_limit_per_file_percent can be specified. This field can’t be set if de-identification is requested. For certain file types, setting this field has no effect. For more information, see Limits on bytes scanned per file.

bytes_limit_per_file_percent: Option<i32>

Max percentage of bytes to scan from a file. The rest are omitted. The number of bytes scanned is rounded down. Must be between 0 and 100, inclusively. Both 0 and 100 means no limit. Defaults to 0. Only one of bytes_limit_per_file and bytes_limit_per_file_percent can be specified. This field can’t be set if de-identification is requested. For certain file types, setting this field has no effect. For more information, see Limits on bytes scanned per file.

file_set: Option<GooglePrivacyDlpV2FileSet>

The set of one or more files to scan.

file_types: Option<Vec<String>>

List of file type groups to include in the scan. If empty, all files are scanned and available data format processors are applied. In addition, the binary content of the selected files is always scanned as well. Images are scanned only as binary if the specified region does not support image inspection and no file_types were specified. Image inspection is restricted to ‘global’, ‘us’, ‘asia’, and ‘europe’.

files_limit_percent: Option<i32>

Limits the number of files to scan to this percentage of the input FileSet. Number of files scanned is rounded down. Must be between 0 and 100, inclusively. Both 0 and 100 means no limit. Defaults to 0.

sample_method: Option<String>

How to sample the data.