GooglePrivacyDlpV2CreateDlpJobRequest

Struct GooglePrivacyDlpV2CreateDlpJobRequest 

pub struct GooglePrivacyDlpV2CreateDlpJobRequest {
    pub inspect_job: Option<GooglePrivacyDlpV2InspectJobConfig>,
    pub job_id: Option<String>,
    pub location_id: Option<String>,
    pub risk_job: Option<GooglePrivacyDlpV2RiskAnalysisJobConfig>,
}
Request message for CreateDlpJobRequest. Used to initiate long running jobs such as calculating risk metrics or inspecting Google Cloud Storage.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

inspect_job: Option<GooglePrivacyDlpV2InspectJobConfig>

An inspection job scans a storage repository for InfoTypes.

job_id: Option<String>

The job id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one.

location_id: Option<String>

Deprecated. This field has no effect.

risk_job: Option<GooglePrivacyDlpV2RiskAnalysisJobConfig>

A risk analysis job calculates re-identification risk metrics for a BigQuery table.