pub struct GooglePrivacyDlpV2CustomInfoType {
pub detection_rules: Option<Vec<GooglePrivacyDlpV2DetectionRule>>,
pub dictionary: Option<GooglePrivacyDlpV2Dictionary>,
pub exclusion_type: Option<String>,
pub info_type: Option<GooglePrivacyDlpV2InfoType>,
pub likelihood: Option<String>,
pub regex: Option<GooglePrivacyDlpV2Regex>,
pub sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>,
pub stored_type: Option<GooglePrivacyDlpV2StoredType>,
pub surrogate_type: Option<GooglePrivacyDlpV2SurrogateType>,
}Expand description
Custom information type provided by the user. Used to find domain-specific sensitive information configurable to the data in question.
This type is not used in any activity, and only used as part of another schema.
Fields
detection_rules: Option<Vec<GooglePrivacyDlpV2DetectionRule>>Set of detection rules to apply to all findings of this CustomInfoType. Rules are applied in order that they are specified. Not supported for the surrogate_type CustomInfoType.
dictionary: Option<GooglePrivacyDlpV2Dictionary>A list of phrases to detect as a CustomInfoType.
exclusion_type: Option<String>If set to EXCLUSION_TYPE_EXCLUDE this infoType will not cause a finding to be returned. It still can be used for rules matching.
info_type: Option<GooglePrivacyDlpV2InfoType>CustomInfoType can either be a new infoType, or an extension of built-in infoType, when the name matches one of existing infoTypes and that infoType is specified in InspectContent.info_types field. Specifying the latter adds findings to the one detected by the system. If built-in info type is not specified in InspectContent.info_types list then the name is treated as a custom info type.
likelihood: Option<String>Likelihood to return for this CustomInfoType. This base value can be altered by a detection rule if the finding meets the criteria specified by the rule. Defaults to VERY_LIKELY if not specified.
regex: Option<GooglePrivacyDlpV2Regex>Regular expression based CustomInfoType.
sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>Sensitivity for this CustomInfoType. If this CustomInfoType extends an existing InfoType, the sensitivity here will take precedence over that of the original InfoType. If unset for a CustomInfoType, it will default to HIGH. This only applies to data profiling.
stored_type: Option<GooglePrivacyDlpV2StoredType>Loads an existing StoredInfoType resource.
surrogate_type: Option<GooglePrivacyDlpV2SurrogateType>Message for detecting output from deidentification transformations that support reversing.