pub struct GooglePrivacyDlpV2DataProfileAction {
pub export_data: Option<GooglePrivacyDlpV2Export>,
pub pub_sub_notification: Option<GooglePrivacyDlpV2PubSubNotification>,
pub publish_to_chronicle: Option<GooglePrivacyDlpV2PublishToChronicle>,
pub publish_to_dataplex_catalog: Option<GooglePrivacyDlpV2PublishToDataplexCatalog>,
pub publish_to_scc: Option<GooglePrivacyDlpV2PublishToSecurityCommandCenter>,
pub tag_resources: Option<GooglePrivacyDlpV2TagResources>,
}Expand description
A task to execute when a data profile has been generated.
This type is not used in any activity, and only used as part of another schema.
Fields
export_data: Option<GooglePrivacyDlpV2Export>Export data profiles into a provided location.
pub_sub_notification: Option<GooglePrivacyDlpV2PubSubNotification>Publish a message into the Pub/Sub topic.
publish_to_chronicle: Option<GooglePrivacyDlpV2PublishToChronicle>Publishes generated data profiles to Google Security Operations. For more information, see Use Sensitive Data Protection data in context-aware analytics.
publish_to_dataplex_catalog: Option<GooglePrivacyDlpV2PublishToDataplexCatalog>Publishes a portion of each profile to Dataplex Universal Catalog with the aspect type Sensitive Data Protection Profile.
publish_to_scc: Option<GooglePrivacyDlpV2PublishToSecurityCommandCenter>Publishes findings to Security Command Center for each data profile.
tag_resources: Option<GooglePrivacyDlpV2TagResources>Tags the profiled resources with the specified tag values.