GooglePrivacyDlpV2DataProfileConfigSnapshot

Struct GooglePrivacyDlpV2DataProfileConfigSnapshot 

pub struct GooglePrivacyDlpV2DataProfileConfigSnapshot {
    pub data_profile_job: Option<GooglePrivacyDlpV2DataProfileJobConfig>,
    pub discovery_config: Option<GooglePrivacyDlpV2DiscoveryConfig>,
    pub inspect_config: Option<GooglePrivacyDlpV2InspectConfig>,
    pub inspect_template_modified_time: Option<DateTime<Utc>>,
    pub inspect_template_name: Option<String>,
}
Snapshot of the configurations used to generate the profile.

This type is not used in any activity, and only used as part of another schema.

Fields

data_profile_job: Option<GooglePrivacyDlpV2DataProfileJobConfig>

A copy of the configuration used to generate this profile. This is deprecated, and the DiscoveryConfig field is preferred moving forward. DataProfileJobConfig will still be written here for Discovery in BigQuery for backwards compatibility, but will not be updated with new fields, while DiscoveryConfig will.

discovery_config: Option<GooglePrivacyDlpV2DiscoveryConfig>

A copy of the configuration used to generate this profile.

inspect_config: Option<GooglePrivacyDlpV2InspectConfig>

A copy of the inspection config used to generate this profile. This is a copy of the inspect_template specified in DataProfileJobConfig.

inspect_template_modified_time: Option<DateTime<Utc>>

Timestamp when the template was modified

inspect_template_name: Option<String>

Name of the inspection template used to generate this profile