pub struct GooglePrivacyDlpV2DetectionRule {
pub hotword_rule: Option<GooglePrivacyDlpV2HotwordRule>,
}Expand description
Deprecated; use InspectionRuleSet instead. Rule for modifying a CustomInfoType to alter behavior under certain circumstances, depending on the specific details of the rule. Not supported for the surrogate_type custom infoType.
This type is not used in any activity, and only used as part of another schema.
Fields
hotword_rule: Option<GooglePrivacyDlpV2HotwordRule>Hotword-based detection rule.