pub struct GooglePrivacyDlpV2ImageTransformations {
pub transforms: Option<Vec<GooglePrivacyDlpV2ImageTransformation>>,
}Expand description
A type of transformation that is applied over images.
This type is not used in any activity, and only used as part of another schema.
Fields
transforms: Option<Vec<GooglePrivacyDlpV2ImageTransformation>>List of transforms to make.