pub struct GooglePrivacyDlpV2InfoType {
pub name: Option<String>,
pub sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>,
pub version: Option<String>,
}Expand description
Type of information detected by the API.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Name of the information type. Either a name of your choosing when creating a CustomInfoType, or one of the names listed at https://cloud.google.com/sensitive-data-protection/docs/infotypes-reference when specifying a built-in type. When sending Cloud DLP results to Data Catalog, infoType names should conform to the pattern [A-Za-z0-9$_-]{1,64}.
sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>Optional custom sensitivity for this InfoType. This only applies to data profiling.
version: Option<String>Optional version name for this InfoType.