pub struct GooglePrivacyDlpV2InfoTypeTransformations {
pub transformations: Option<Vec<GooglePrivacyDlpV2InfoTypeTransformation>>,
}Expand description
A type of transformation that will scan unstructured text and apply various PrimitiveTransformations to each finding, where the transformation is applied to only values that were identified as a specific info_type.
This type is not used in any activity, and only used as part of another schema.
Fields
transformations: Option<Vec<GooglePrivacyDlpV2InfoTypeTransformation>>Required. Transformation for each infoType. Cannot specify more than one for a given infoType.