GooglePrivacyDlpV2InspectConfig

Struct GooglePrivacyDlpV2InspectConfig 

pub struct GooglePrivacyDlpV2InspectConfig {
    pub content_options: Option<Vec<String>>,
    pub custom_info_types: Option<Vec<GooglePrivacyDlpV2CustomInfoType>>,
    pub exclude_info_types: Option<bool>,
    pub include_quote: Option<bool>,
    pub info_types: Option<Vec<GooglePrivacyDlpV2InfoType>>,
    pub limits: Option<GooglePrivacyDlpV2FindingLimits>,
    pub min_likelihood: Option<String>,
    pub min_likelihood_per_info_type: Option<Vec<GooglePrivacyDlpV2InfoTypeLikelihood>>,
    pub rule_set: Option<Vec<GooglePrivacyDlpV2InspectionRuleSet>>,
}
Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used.

This type is not used in any activity, and only used as part of another schema.

Fields

content_options: Option<Vec<String>>

Deprecated and unused.

custom_info_types: Option<Vec<GooglePrivacyDlpV2CustomInfoType>>

CustomInfoTypes provided by the user. See https://cloud.google.com/sensitive-data-protection/docs/creating-custom-infotypes to learn more.

exclude_info_types: Option<bool>

When true, excludes type information of the findings. This is not used for data profiling.

include_quote: Option<bool>

When true, a contextual quote from the data that triggered a finding is included in the response; see Finding.quote. This is not used for data profiling.

info_types: Option<Vec<GooglePrivacyDlpV2InfoType>>

Restricts what info_types to look for. The values must correspond to InfoType values returned by ListInfoTypes or listed at https://cloud.google.com/sensitive-data-protection/docs/infotypes-reference. When no InfoTypes or CustomInfoTypes are specified in a request, the system may automatically choose a default list of detectors to run, which may change over time. If you need precise control and predictability as to what detectors are run you should specify specific InfoTypes listed in the reference, otherwise a default list will be used, which may change over time.

limits: Option<GooglePrivacyDlpV2FindingLimits>

Configuration to control the number of findings returned. This is not used for data profiling. When redacting sensitive data from images, finding limits don’t apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don’t include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error. When set within an InspectJobConfig, the specified maximum values aren’t hard limits. If an inspection job reaches these limits, the job ends gradually, not abruptly. Therefore, the actual number of findings that Cloud DLP returns can be multiple times higher than these maximum values.

min_likelihood: Option<String>

Only returns findings equal to or above this threshold. The default is POSSIBLE. In general, the highest likelihood setting yields the fewest findings in results and the lowest chance of a false positive. For more information, see Match likelihood.

min_likelihood_per_info_type: Option<Vec<GooglePrivacyDlpV2InfoTypeLikelihood>>

Minimum likelihood per infotype. For each infotype, a user can specify a minimum likelihood. The system only returns a finding if its likelihood is above this threshold. If this field is not set, the system uses the InspectConfig min_likelihood.

rule_set: Option<Vec<GooglePrivacyDlpV2InspectionRuleSet>>

Set of rules to apply to the findings for this InspectConfig. Exclusion rules, contained in the set are executed in the end, other rules are executed in the order they are specified for each info type.