pub struct GooglePrivacyDlpV2InspectContentRequest {
pub inspect_config: Option<GooglePrivacyDlpV2InspectConfig>,
pub inspect_template_name: Option<String>,
pub item: Option<GooglePrivacyDlpV2ContentItem>,
pub location_id: Option<String>,
}Expand description
Request to search for potentially sensitive info in a ContentItem.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- content inspect projects (request)
- locations content inspect projects (request)
Fields
inspect_config: Option<GooglePrivacyDlpV2InspectConfig>Configuration for the inspector. What specified here will override the template referenced by the inspect_template_name argument.
inspect_template_name: Option<String>Template to use. Any configuration directly specified in inspect_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged.
item: Option<GooglePrivacyDlpV2ContentItem>The item to inspect.
location_id: Option<String>Deprecated. This field has no effect.