pub struct GooglePrivacyDlpV2InspectionRuleSet {
pub info_types: Option<Vec<GooglePrivacyDlpV2InfoType>>,
pub rules: Option<Vec<GooglePrivacyDlpV2InspectionRule>>,
}Expand description
Rule set for modifying a set of infoTypes to alter behavior under certain circumstances, depending on the specific details of the rules within the set.
This type is not used in any activity, and only used as part of another schema.
Fields
info_types: Option<Vec<GooglePrivacyDlpV2InfoType>>List of infoTypes this rule set is applied to.
rules: Option<Vec<GooglePrivacyDlpV2InspectionRule>>Set of rules to be applied to infoTypes. The rules are applied in order.