pub struct GooglePrivacyDlpV2ListProjectDataProfilesResponse {
pub next_page_token: Option<String>,
pub project_data_profiles: Option<Vec<GooglePrivacyDlpV2ProjectDataProfile>>,
}Expand description
List of profiles generated for a given organization or project.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>The next page token.
project_data_profiles: Option<Vec<GooglePrivacyDlpV2ProjectDataProfile>>List of data profiles.