pub struct GooglePrivacyDlpV2ProcessingLocation {
pub document_fallback_location: Option<GooglePrivacyDlpV2DocumentFallbackLocation>,
pub image_fallback_location: Option<GooglePrivacyDlpV2ImageFallbackLocation>,
}Expand description
Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided.
This type is not used in any activity, and only used as part of another schema.
Fields
document_fallback_location: Option<GooglePrivacyDlpV2DocumentFallbackLocation>Document processing falls back using this configuration.
image_fallback_location: Option<GooglePrivacyDlpV2ImageFallbackLocation>Image processing falls back using this configuration.