pub struct GooglePrivacyDlpV2ProjectDataProfile {
pub data_risk_level: Option<GooglePrivacyDlpV2DataRiskLevel>,
pub file_store_data_profile_count: Option<i64>,
pub name: Option<String>,
pub profile_last_generated: Option<DateTime<Utc>>,
pub profile_status: Option<GooglePrivacyDlpV2ProfileStatus>,
pub project_id: Option<String>,
pub sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>,
pub table_data_profile_count: Option<i64>,
}Expand description
An aggregated profile for this project, based on the resources profiled within it.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
data_risk_level: Option<GooglePrivacyDlpV2DataRiskLevel>The data risk level of this project.
file_store_data_profile_count: Option<i64>The number of file store data profiles generated for this project.
name: Option<String>The resource name of the profile.
profile_last_generated: Option<DateTime<Utc>>The last time the profile was generated.
profile_status: Option<GooglePrivacyDlpV2ProfileStatus>Success or error status of the last attempt to profile the project.
project_id: Option<String>Project ID or account that was profiled.
sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>The sensitivity score of this project.
table_data_profile_count: Option<i64>The number of table data profiles generated for this project.