pub struct GooglePrivacyDlpV2RecordTransformations {
pub field_transformations: Option<Vec<GooglePrivacyDlpV2FieldTransformation>>,
pub record_suppressions: Option<Vec<GooglePrivacyDlpV2RecordSuppression>>,
}Expand description
A type of transformation that is applied over structured data such as a table.
This type is not used in any activity, and only used as part of another schema.
Fields
field_transformations: Option<Vec<GooglePrivacyDlpV2FieldTransformation>>Transform the record by applying various field transformations.
record_suppressions: Option<Vec<GooglePrivacyDlpV2RecordSuppression>>Configuration defining which records get suppressed entirely. Records that match any suppression rule are omitted from the output.