pub struct GooglePrivacyDlpV2SensitivityScore {
pub score: Option<String>,
}Expand description
Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.
This type is not used in any activity, and only used as part of another schema.
Fields
score: Option<String>The sensitivity score applied to the resource.