pub struct GooglePrivacyDlpV2StorageConfig {
pub big_query_options: Option<GooglePrivacyDlpV2BigQueryOptions>,
pub cloud_storage_options: Option<GooglePrivacyDlpV2CloudStorageOptions>,
pub datastore_options: Option<GooglePrivacyDlpV2DatastoreOptions>,
pub hybrid_options: Option<GooglePrivacyDlpV2HybridOptions>,
pub timespan_config: Option<GooglePrivacyDlpV2TimespanConfig>,
}Expand description
Shared message indicating Cloud storage type.
This type is not used in any activity, and only used as part of another schema.
Fields
big_query_options: Option<GooglePrivacyDlpV2BigQueryOptions>BigQuery options.
cloud_storage_options: Option<GooglePrivacyDlpV2CloudStorageOptions>Cloud Storage options.
datastore_options: Option<GooglePrivacyDlpV2DatastoreOptions>Google Cloud Datastore options.
hybrid_options: Option<GooglePrivacyDlpV2HybridOptions>Hybrid inspection options.
timespan_config: Option<GooglePrivacyDlpV2TimespanConfig>Configuration of the timespan of the items to include in scanning.