pub struct GooglePrivacyDlpV2Tag {
pub key: Option<String>,
pub namespaced_tag_value: Option<String>,
pub value: Option<String>,
}Expand description
A tag associated with a resource.
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>The key of a tag key-value pair. For Google Cloud resources, this is the resource name of the key, for example, “tagKeys/123456”.
namespaced_tag_value: Option<String>The namespaced name for the tag value to attach to Google Cloud resources. Must be in the format {parent_id}/{tag_key_short_name}/{short_name}, for example, “123456/environment/prod” for an organization parent, or “my-project/environment/prod” for a project parent. This is only set for Google Cloud resources.
value: Option<String>The value of a tag key-value pair. For Google Cloud resources, this is the resource name of the value, for example, “tagValues/123456”.