pub struct GooglePrivacyDlpV2Trigger {
pub manual: Option<GooglePrivacyDlpV2Manual>,
pub schedule: Option<GooglePrivacyDlpV2Schedule>,
}Expand description
What event needs to occur for a new job to be started.
This type is not used in any activity, and only used as part of another schema.
Fields
manual: Option<GooglePrivacyDlpV2Manual>For use with hybrid jobs. Jobs must be manually created and finished.
schedule: Option<GooglePrivacyDlpV2Schedule>Create a job on a repeating basis based on the elapse of time.