pub struct GooglePrivacyDlpV2Value {
pub boolean_value: Option<bool>,
pub date_value: Option<GoogleTypeDate>,
pub day_of_week_value: Option<String>,
pub float_value: Option<f64>,
pub integer_value: Option<i64>,
pub string_value: Option<String>,
pub time_value: Option<GoogleTypeTimeOfDay>,
pub timestamp_value: Option<DateTime<Utc>>,
}Expand description
Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ‘Value’ is based on its representation as a UTF-8 encoded string. For example, if ‘integer_value’ is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data.
This type is not used in any activity, and only used as part of another schema.
Fields
boolean_value: Option<bool>boolean
date_value: Option<GoogleTypeDate>date
day_of_week_value: Option<String>day of week
float_value: Option<f64>float
integer_value: Option<i64>integer
string_value: Option<String>string
time_value: Option<GoogleTypeTimeOfDay>time of day
timestamp_value: Option<DateTime<Utc>>timestamp