Struct google_dlp2::GooglePrivacyDlpV2CreateJobTriggerRequest[][src]

pub struct GooglePrivacyDlpV2CreateJobTriggerRequest {
    pub trigger_id: Option<String>,
    pub job_trigger: Option<GooglePrivacyDlpV2JobTrigger>,
}

Request message for CreateJobTrigger.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

The trigger id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\\d-]+. The maximum length is 100 characters. Can be empty to allow the system to generate one.

The JobTrigger to create.