pub struct GooglePrivacyDlpV2Connection {
pub cloud_sql: Option<GooglePrivacyDlpV2CloudSqlProperties>,
pub errors: Option<Vec<GooglePrivacyDlpV2Error>>,
pub name: Option<String>,
pub state: Option<String>,
}Expand description
A data connection to allow the DLP API to profile data in locations that require additional configuration.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations connections create organizations (response)
- locations connections get organizations (response)
- locations connections patch organizations (response)
- locations connections create projects (response)
- locations connections get projects (response)
- locations connections patch projects (response)
Fields
cloud_sql: Option<GooglePrivacyDlpV2CloudSqlProperties>Connect to a Cloud SQL instance.
errors: Option<Vec<GooglePrivacyDlpV2Error>>Output only. Set if status == ERROR, to provide additional details. Will store the last 10 errors sorted with the most recent first.
name: Option<String>Output only. Name of the connection: projects/{project}/locations/{location}/connections/{name}.
state: Option<String>Required. The connection’s state in its lifecycle.