pub struct GooglePrivacyDlpV2FileClusterSummary {
pub data_risk_level: Option<GooglePrivacyDlpV2DataRiskLevel>,
pub errors: Option<Vec<GooglePrivacyDlpV2Error>>,
pub file_cluster_type: Option<GooglePrivacyDlpV2FileClusterType>,
pub file_extensions_scanned: Option<Vec<GooglePrivacyDlpV2FileExtensionInfo>>,
pub file_extensions_seen: Option<Vec<GooglePrivacyDlpV2FileExtensionInfo>>,
pub file_store_info_type_summaries: Option<Vec<GooglePrivacyDlpV2FileStoreInfoTypeSummary>>,
pub no_files_exist: Option<bool>,
pub sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>,
}Expand description
The file cluster summary.
This type is not used in any activity, and only used as part of another schema.
Fields
data_risk_level: Option<GooglePrivacyDlpV2DataRiskLevel>The data risk level of this cluster. RISK_LOW if nothing has been scanned.
errors: Option<Vec<GooglePrivacyDlpV2Error>>A list of errors detected while scanning this cluster. The list is truncated to 10 per cluster.
file_cluster_type: Option<GooglePrivacyDlpV2FileClusterType>The file cluster type.
file_extensions_scanned: Option<Vec<GooglePrivacyDlpV2FileExtensionInfo>>A sample of file types scanned in this cluster. Empty if no files were scanned. File extensions can be derived from the file name or the file content.
file_extensions_seen: Option<Vec<GooglePrivacyDlpV2FileExtensionInfo>>A sample of file types seen in this cluster. Empty if no files were seen. File extensions can be derived from the file name or the file content.
file_store_info_type_summaries: Option<Vec<GooglePrivacyDlpV2FileStoreInfoTypeSummary>>InfoTypes detected in this cluster.
no_files_exist: Option<bool>True if no files exist in this cluster. If the file store had more files than could be listed, this will be false even if no files for this cluster were seen and file_extensions_seen is empty.
sensitivity_score: Option<GooglePrivacyDlpV2SensitivityScore>The sensitivity score of this cluster. The score will be SENSITIVITY_LOW if nothing has been scanned.