pub struct GooglePrivacyDlpV2TransformationErrorHandling {
pub leave_untransformed: Option<GooglePrivacyDlpV2LeaveUntransformed>,
pub throw_error: Option<GooglePrivacyDlpV2ThrowError>,
}Expand description
How to handle transformation errors during de-identification. A transformation error occurs when the requested transformation is incompatible with the data. For example, trying to de-identify an IP address using a DateShift transformation would result in a transformation error, since date info cannot be extracted from an IP address. Information about any incompatible transformations, and how they were handled, is returned in the response as part of the TransformationOverviews.
This type is not used in any activity, and only used as part of another schema.
Fields
leave_untransformed: Option<GooglePrivacyDlpV2LeaveUntransformed>Ignore errors
throw_error: Option<GooglePrivacyDlpV2ThrowError>Throw an error